@@ -4,7 +4,7 @@ use std::io::Error;
 /// Return the number of logical core the system has.
 ///
 /// And on macOS it will make a syscall to sysctl with hw.logicalcpu.
-pub fn get_cpu_logical_count() -> Result<i64, Error> {
+pub fn get_cpu_logical_count() -> Result<u32, Error> {
     let mut data: c_uint = 0;
     let mut mib: [i32; 2] = [6, 25];
 
@@ -35,5 +35,5 @@ pub fn get_cpu_logical_count() -> Result<i64, Error> {
         }
     }
 
-    Ok(data.into())
+    Ok(data)
 }
